@@ -54,9 +54,12 @@ SEXP submatprod(SEXP M, SEXP v, SEXP am, SEXP nr, SEXP nc) {
 SEXP subprod(SEXP X, SEXP M, SEXP v, SEXP a, SEXP z, SEXP nv) {
   R_len_t i = INTEGER(a)[0], j = 0, 
     last = INTEGER(z)[0], len_v = INTEGER(nv)[0];
-
+  double *dX, *dM, *dv;
+  dX = REAL(X);
+  dM = REAL(M);
+  dv = REAL(v);
   for ( ; i <= last; j = (++j == len_v) ? 0 : j) { 
-    REAL(X)[i] = REAL(M)[i] * REAL(v)[j];
+    dX[i] = dM[i] * dv[j];
     i++;
   }
   return(X);
@@ -67,10 +70,12 @@ SEXP subprod(SEXP X, SEXP M, SEXP v, SEXP a, SEXP z, SEXP nv) {
 SEXP nonlin(SEXP X, SEXP a, SEXP z, SEXP expr, SEXP rho) {
   R_len_t i = INTEGER(a)[0], i1 = 0, last = INTEGER(z)[0];
   SEXP ans;
-
+  double *dX, *dans;
+  dX = REAL(X);
   PROTECT(ans = coerceVector(eval(expr, rho), REALSXP));
+  dans = REAL(ans);
   for ( ; i <= last;) {
-    REAL(X)[i++] = REAL(ans)[i1++];
+    dX[i++] = dans[i1++];
   }
   UNPROTECT(1);
   return(X);
@@ -83,27 +88,31 @@ SEXP nonlin(SEXP X, SEXP a, SEXP z, SEXP expr, SEXP rho) {
 SEXP newsubprod(SEXP M, SEXP V, SEXP X, SEXP a, SEXP b, SEXP c, 
 		  SEXP nt, SEXP lt, SEXP ls, SEXP nr, SEXP nc, SEXP max) {
   /* currently set up for single term so nt = 1 and all integers here */
-  int i, j, k, l, start, end, common, nrow = INTEGER(nr)[0], 
-    n = INTEGER(max)[0], final, jump;
-  double *p[n], *q[n];
+  int i, j, k, l, *start, *end, *common, nrow = INTEGER(nr)[0], 
+	  n = INTEGER(max)[0], final = INTEGER(nt)[0], *jump, *ia, *ib;
+  double *p[n], *q[n], *dM, *dV, *dX;
 
-  final = INTEGER(nt)[0];
+  dM = REAL(M);
+  dV = REAL(V);
+  dX = REAL(X);
+  start = INTEGER(c);
+  end = INTEGER(ls);
+  common = INTEGER(nc);
+  jump = INTEGER(lt);
+  ia = INTEGER(a);
+  ib = INTEGER(b);
   for (i = 0; i < final; i++){
-    common = INTEGER(nc)[i];
-    jump = INTEGER(lt)[i];
-    p[0] = &REAL(M)[INTEGER(a)[i]];
-    q[0] = &REAL(V)[INTEGER(b)[i]];
-    for (l = 1; l < common; l++) {
-      p[l] = p[l - 1] + jump;
+    p[0] = &dM[ia[i]];
+    q[0] = &dV[ib[i]];
+    for (l = 1; l < common[i]; l++) {
+      p[l] = p[l - 1] + jump[i];
       q[l] = q[l - 1] + nrow;
     }
-    start = INTEGER(c)[i];
-    end = INTEGER(ls)[i];
     k = 0;
-    for (j = start; j < end; j++, k = (++k == nrow) ? 0 : k) {
-      REAL(X)[j] = *(p[0])++ * q[0][k];
-      for (l = 1; l < common; l++){
-	REAL(X)[j] += *(p[l])++ * q[l][k];
+    for (j = start[i]; j < end[i]; j++, k = (++k == nrow) ? 0 : k) {
+      dX[j] = *(p[0])++ * q[0][k];
+      for (l = 1; l < common[i]; l++){
+	dX[j] += *(p[l])++ * q[l][k];
       }
     }
   }
@@ -112,7 +121,7 @@ SEXP newsubprod(SEXP M, SEXP V, SEXP X, SEXP a, SEXP b, SEXP c,
 /* computes single column of design matrix */
 SEXP single(SEXP M, SEXP V, SEXP a, SEXP lt, SEXP nr, SEXP nc) {
   int j, k, l, nrow = INTEGER(nr)[0], common = INTEGER(nc)[0], jump;
-  double *p[common], *q[common];
+  double *p[common], *q[common], *dcol;
   SEXP col;
 
   jump = INTEGER(lt)[0];
@@ -124,10 +133,11 @@ SEXP single(SEXP M, SEXP V, SEXP a, SEXP lt, SEXP nr, SEXP nc) {
   }
   k = 0;
   PROTECT(col = allocVector(REALSXP, nrow));
+  dcol = REAL(col);
   for (j = 0; j < nrow; j++, k = (++k == nrow) ? 0 : k) {
-    REAL(col)[j] = *(p[0])++ * q[0][k];
+    dcol[j] = *(p[0])++ * q[0][k];
     for (l = 1; l < common; l++){
-      REAL(col)[j] += *(p[l])++ * q[l][k];
+      dcol[j] += *(p[l])++ * q[l][k];
     }
   }
   UNPROTECT(1);
